==> gwyddion_2.44.orig.tar.xz: gwyddion-2.44/libprocess/gwyprocesstypes.h <==
/* This is a GENERATED file. */
/* Generated data (by glib-mkenums) */

#ifndef __GWY_PROCESS_TYPES_H__
#define __GWY_PROCESS_TYPES_H__

#include <glib-object.h>

G_BEGIN_DECLS

GType gwy_merge_type_get_type(void) G_GNUC_CONST;
#define GWY_TYPE_MERGE_TYPE (gwy_merge_type_get_type())

GType gwy_masking_type_get_type(void) G_GNUC_CONST;
#define GWY_TYPE_MASKING_TYPE (gwy_masking_type_get_type())

GType gwy_watershed_state_type_get_type(void) G_GNUC_CONST;
#define GWY_TYPE_WATERSHED_STATE_TYPE (gwy_watershed_state_type_get_type())

GType gwy_plane_symmetry_get_type(void) G_GNUC_CONST;
#define GWY_TYPE_PLANE_SYMMETRY (gwy_plane_symmetry_get_type())

GType gwy_2d_cwt_wavelet_type_get_type(void) G_GNUC_CONST;
#define GWY_TYPE_2D_CWT_WAVELET_TYPE (gwy_2d_cwt_wavelet_type_get_type())

GType gwy_orientation_get_type(void) G_GNUC_CONST;
#define GWY_TYPE_ORIENTATION (gwy_orientation_get_type())

GType gwy_transform_direction_get_type(void) G_GNUC_CONST;
#define GWY_TYPE_TRANSFORM_DIRECTION (gwy_transform_direction_get_type())

GType gwy_data_field_cached_get_type(void) G_GNUC_CONST;
#define GWY_TYPE_DATA_FIELD_CACHED (gwy_data_field_cached_get_type())

GType gwy_computation_state_type_get_type(void) G_GNUC_CONST;
#define GWY_TYPE_COMPUTATION_STATE_TYPE (gwy_computation_state_type_get_type())

GType gwy_dwt_type_get_type(void) G_GNUC_CONST;
#define GWY_TYPE_DWT_TYPE (gwy_dwt_type_get_type())

GType gwy_dwt_denoise_type_get_type(void) G_GNUC_CONST;
#define GWY_TYPE_DWT_DENOISE_TYPE (gwy_dwt_denoise_type_get_type())

GType gwy_interpolation_type_get_type(void) G_GNUC_CONST;
#define GWY_TYPE_INTERPOLATION_TYPE (gwy_interpolation_type_get_type())

GType gwy_plane_fit_quantity_get_type(void) G_GNUC_CONST;
#define GWY_TYPE_PLANE_FIT_QUANTITY (gwy_plane_fit_quantity_get_type())

GType gwy_windowing_type_get_type(void) G_GNUC_CONST;
#define GWY_TYPE_WINDOWING_TYPE (gwy_windowing_type_get_type())

GType gwy_tip_type_get_type(void) G_GNUC_CONST;
#define GWY_TYPE_TIP_TYPE (gwy_tip_type_get_type())

GType gwy_correlation_type_get_type(void) G_GNUC_CONST;
#define GWY_TYPE_CORRELATION_TYPE (gwy_correlation_type_get_type())

GType gwy_grain_quantity_get_type(void) G_GNUC_CONST;
#define GWY_TYPE_GRAIN_QUANTITY (gwy_grain_quantity_get_type())

GType gwy_data_compatibility_flags_get_type(void) G_GNUC_CONST;
#define GWY_TYPE_DATA_COMPATIBILITY_FLAGS (gwy_data_compatibility_flags_get_type())

GType gwy_line_stat_quantity_get_type(void) G_GNUC_CONST;
#define GWY_TYPE_LINE_STAT_QUANTITY (gwy_line_stat_quantity_get_type())

GType gwy_exterior_type_get_type(void) G_GNUC_CONST;
#define GWY_TYPE_EXTERIOR_TYPE (gwy_exterior_type_get_type())

GType gwy_distance_transform_type_get_type(void) G_GNUC_CONST;
#define GWY_TYPE_DISTANCE_TRANSFORM_TYPE (gwy_distance_transform_type_get_type())

GType gwy_min_max_filter_type_get_type(void) G_GNUC_CONST;
#define GWY_TYPE_MIN_MAX_FILTER_TYPE (gwy_min_max_filter_type_get_type())

GType gwy_grain_value_group_get_type(void) G_GNUC_CONST;
#define GWY_TYPE_GRAIN_VALUE_GROUP (gwy_grain_value_group_get_type())

GType gwy_grain_value_flags_get_type(void) G_GNUC_CONST;
#define GWY_TYPE_GRAIN_VALUE_FLAGS (gwy_grain_value_flags_get_type())

G_END_DECLS

#endif /* __GWY_PROCESS_TYPES_H__ */

/* Generated data ends here */

==> gwyddion_2.47.orig.tar.xz: gwyddion-2.47/libprocess/gwyprocesstypes.h <==
/* This is a GENERATED file. */
/* Generated data (by glib-mkenums) */

#ifndef __GWY_PROCESS_TYPES_H__
#define __GWY_PROCESS_TYPES_H__

#include <glib-object.h>

G_BEGIN_DECLS

GType gwy_merge_type_get_type(void) G_GNUC_CONST;
#define GWY_TYPE_MERGE_TYPE (gwy_merge_type_get_type())

GType gwy_masking_type_get_type(void) G_GNUC_CONST;
#define GWY_TYPE_MASKING_TYPE (gwy_masking_type_get_type())

GType gwy_watershed_state_type_get_type(void) G_GNUC_CONST;
#define GWY_TYPE_WATERSHED_STATE_TYPE (gwy_watershed_state_type_get_type())

GType gwy_plane_symmetry_get_type(void) G_GNUC_CONST;
#define GWY_TYPE_PLANE_SYMMETRY (gwy_plane_symmetry_get_type())

GType gwy_2d_cwt_wavelet_type_get_type(void) G_GNUC_CONST;
#define GWY_TYPE_2D_CWT_WAVELET_TYPE (gwy_2d_cwt_wavelet_type_get_type())

GType gwy_orientation_get_type(void) G_GNUC_CONST;
#define GWY_TYPE_ORIENTATION (gwy_orientation_get_type())

GType gwy_transform_direction_get_type(void) G_GNUC_CONST;
#define GWY_TYPE_TRANSFORM_DIRECTION (gwy_transform_direction_get_type())

GType gwy_data_field_cached_get_type(void) G_GNUC_CONST;
#define GWY_TYPE_DATA_FIELD_CACHED (gwy_data_field_cached_get_type())

GType gwy_computation_state_type_get_type(void) G_GNUC_CONST;
#define GWY_TYPE_COMPUTATION_STATE_TYPE (gwy_computation_state_type_get_type())

GType gwy_dwt_type_get_type(void) G_GNUC_CONST;
#define GWY_TYPE_DWT_TYPE (gwy_dwt_type_get_type())

GType gwy_dwt_denoise_type_get_type(void) G_GNUC_CONST;
#define GWY_TYPE_DWT_DENOISE_TYPE (gwy_dwt_denoise_type_get_type())

GType gwy_interpolation_type_get_type(void) G_GNUC_CONST;
#define GWY_TYPE_INTERPOLATION_TYPE (gwy_interpolation_type_get_type())

GType gwy_plane_fit_quantity_get_type(void) G_GNUC_CONST;
#define GWY_TYPE_PLANE_FIT_QUANTITY (gwy_plane_fit_quantity_get_type())

GType gwy_windowing_type_get_type(void) G_GNUC_CONST;
#define GWY_TYPE_WINDOWING_TYPE (gwy_windowing_type_get_type())

GType gwy_tip_type_get_type(void) G_GNUC_CONST;
#define GWY_TYPE_TIP_TYPE (gwy_tip_type_get_type())

GType gwy_tip_param_type_get_type(void) G_GNUC_CONST;
#define GWY_TYPE_TIP_PARAM_TYPE (gwy_tip_param_type_get_type())

GType gwy_correlation_type_get_type(void) G_GNUC_CONST;
#define GWY_TYPE_CORRELATION_TYPE (gwy_correlation_type_get_type())

GType gwy_grain_quantity_get_type(void) G_GNUC_CONST;
#define GWY_TYPE_GRAIN_QUANTITY (gwy_grain_quantity_get_type())

GType gwy_data_compatibility_flags_get_type(void) G_GNUC_CONST;
#define GWY_TYPE_DATA_COMPATIBILITY_FLAGS (gwy_data_compatibility_flags_get_type())

GType gwy_line_stat_quantity_get_type(void) G_GNUC_CONST;
#define GWY_TYPE_LINE_STAT_QUANTITY (gwy_line_stat_quantity_get_type())

GType gwy_exterior_type_get_type(void) G_GNUC_CONST;
#define GWY_TYPE_EXTERIOR_TYPE (gwy_exterior_type_get_type())

GType gwy_distance_transform_type_get_type(void) G_GNUC_CONST;
#define GWY_TYPE_DISTANCE_TRANSFORM_TYPE (gwy_distance_transform_type_get_type())

GType gwy_min_max_filter_type_get_type(void) G_GNUC_CONST;
#define GWY_TYPE_MIN_MAX_FILTER_TYPE (gwy_min_max_filter_type_get_type())

GType gwy_rotate_resize_type_get_type(void) G_GNUC_CONST;
#define GWY_TYPE_ROTATE_RESIZE_TYPE (gwy_rotate_resize_type_get_type())

GType gwy_peak_background_type_get_type(void) G_GNUC_CONST;
#define GWY_TYPE_PEAK_BACKGROUND_TYPE (gwy_peak_background_type_get_type())

GType gwy_peak_order_type_get_type(void) G_GNUC_CONST;
#define GWY_TYPE_PEAK_ORDER_TYPE (gwy_peak_order_type_get_type())

GType gwy_peak_quantity_get_type(void) G_GNUC_CONST;
#define GWY_TYPE_PEAK_QUANTITY (gwy_peak_quantity_get_type())

GType gwy_grain_value_group_get_type(void) G_GNUC_CONST;
#define GWY_TYPE_GRAIN_VALUE_GROUP (gwy_grain_value_group_get_type())

GType gwy_grain_value_flags_get_type(void) G_GNUC_CONST;
#define GWY_TYPE_GRAIN_VALUE_FLAGS (gwy_grain_value_flags_get_type())

G_END_DECLS

#endif /* __GWY_PROCESS_TYPES_H__ */

/* Generated data ends here */
